Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( Config = BuildConfig{ BaseImage: "https://cloud.debian.org/images/cloud/bookworm/daily/latest/debian-12-generic-amd64-daily.raw", VMBaseImageQcow: "https://cloud.debian.org/images/cloud/bookworm/daily/latest/debian-12-generic-amd64-daily.qcow2", VMBaseImageRaw: "https://cloud.debian.org/images/cloud/bookworm/daily/latest/debian-12-generic-amd64-daily.raw", ContainerRegistry: "docker.io", HostFiles: map[string]string{ "/usr/local/bin/rhyzome-agent": "https://codeberg.org/api/packages/EntanglementGarden/generic/rhyzome/b54d3dc/rhyzome-agent", "/opt/step.deb": "https://dl.step.sm/gh-release/cli/gh-release-header/v0.23.2/step-cli_0.23.2_amd64.deb", }, Defaults: InstallOptions{ SuperuserName: "admin", SuperuserPasswordPlaintext: "changeme", ExtraPackages: []string{"jq", "tmux", "tmate", "htop", "mosh"}, }, } )
Functions ¶
This section is empty.
Types ¶
type BuildConfig ¶
type BuildConfig struct {
BaseImage string // URL to image to use for the hypervisor.
VMBaseImageQcow string // override base image for services VM
VMBaseImageRaw string
SSHKeys []string // SSH keys to add to the hypervisor and services VM (user: debian)
ContainerRegistry string // docker hub proxy to use
HostFiles map[string]string // files to download to the hypervisor's root disk. key is the path on disk to the destination, value is the URL. mode will always be 755 (executable)
AptMirrors []cloudinit.AptMirror // select an apt mirror for the hypervisor and services VM. the default will be used if unspecified
Defaults InstallOptions // bake defaults into the installer image. These will be prefilled in the TUI
Headless bool // skip all interactive configuration, just use the configured defaults and install
}
type InstallOptions ¶
type InstallOptions struct {
RootDisk string
WAN string
SSHKeys []string
Domain string
PublicIP string
PublicSubnet string
PublicGateway string
ExtraPackages []string // Extra packages to install on the hypervisor
SuperuserName string // username for the root user
SuperuserEmail string // email address for root user. currently stored for future use but never verified or used. Will NEVER be sent to any server outside of this installation without separate explicit approval
SuperuserPasswordPlaintext string // plaintext password for the superuser. Ignored if SuperuserPasswordHashed is set
SuperuserPasswordHashed string // hash of the superuser password in a format that Ory Kratos will accept (https://www.ory.sh/docs/kratos/manage-identities/import-user-accounts-identities#hashed-passwords). If set, SuperuserPasswordPlaintext is ignored.
}
Source Files
¶
- build-config-defaults.go
Click to show internal directories.
Click to hide internal directories.